@@ -981,11 +981,12 @@
     var insertImages = function(welEditable, files) {
       welEditable.trigger('focus');
       $.each(files, function(idx, file) {
-        var fileReader = new FileReader;
-        fileReader.onload = function(event) {
-          editor.insertImage(welEditable, event.target.result); // sURL
-        };
-        fileReader.readAsDataURL(file);
+          console.log(file);
+//        var fileReader = new FileReader;
+//        fileReader.onload = function(event) {
+//          editor.insertImage(welEditable, event.target.result); // sURL
+//        };
+//        fileReader.readAsDataURL(file);
       });
     };
 
